#
# spec file for package lazarus
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2008-2009 oc2pus
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           lazarus
Version:        1.6.2
Release:        1.13
# Please note that the LGPL is modified and this is not multi-licensed, but each component has a separate license chosen.
License:        GPL-2.0 and LGPL-2.0 and MPL-1.1
Summary:        FreePascal RAD IDE and Component Library
Url:            http://www.lazarus.freepascal.org/
Group:          Development/Languages/Other
Source0:        http://downloads.sourceforge.net/%{name}/%{name}-%{version}-0.tar.gz
Source90:       %{name}-rpmlintrc
# PATCH-FIX-OPENSUSE lazarus-Makefile_patch.diff -- Change installation path from /usr/share/lazarus to /usr/lib(64)/lazarus
Patch0:         %{name}-Makefile_patch.diff
# PATCH-FIX-OPENSUSE lazarus.desktop.patch -- Fix desktop file
Patch1:         lazarus.desktop.patch
%if 0%{?suse_version} > 1210
BuildRequires:  desktop-file-utils
%else
BuildRequires:  update-desktop-files
%endif
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  fpc >= 3.0.0
BuildRequires:  fpc-src >= 3.0.0
%if 0%{?suse_version} >= 1140
BuildRequires:  hicolor-icon-theme
%endif
%if 0%{?sles_version} >= 11
BuildRequires:  glib2-devel
BuildRequires:  gtk2-devel
%else
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-2.0)
%endif
Requires:       fpc
Requires:       fpc-src
Requires:       gdb
%if 0%{?sles_version} >= 11
Requires:       glib2-devel
Requires:       gtk2-devel
%else
Requires:       pkgconfig(glib-2.0)
Requires:       pkgconfig(gtk+-2.0)
%endif
Requires(post): desktop-file-utils
Requires(post): shared-mime-info
Requires(postun): desktop-file-utils
Requires(postun): shared-mime-info
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Lazarus is a free and open source Rapid Application Development
tool for the FreePascal compiler using the Lazarus component
library - LCL. The LCL is included in this package.

%prep
%setup -q -n %{name}
%patch0 -p1
%patch1 -p1

# remove unneeded files
rm -rf debian
rm -rf tools/install/cross_unix/debian_crosswin32/
rm -f tools/install/cross_unix/*deb.*
rm -rf tools/install/debian_*
rm -rf tools/install/freebsd_*
rm -rf tools/install/macosx/
rm -rf tools/install/slacktgz/
rm -rf tools/install/win/
rm -f tools/install/*slacktgz.*

# remove scripts vulnerable to symlink-attacks (bug 460642)
rm tools/install/build_fpc_snaphot_rpm.sh
rm tools/install/check_fpc_dependencies.sh
rm tools/install/create_fpc_deb.sh
rm tools/install/create_fpc_export_tgz.sh
rm tools/install/create_fpc_rpm.sh
rm tools/install/create_fpc-src_rpm.sh
rm tools/install/create_fpc_tgz_from_local_dir.sh
rm tools/install/create_lazarus_export_tgz.sh

# fix lineencodings
dos2unix examples/gridexamples/grid_semaphor/example/table0*.stb
dos2unix examples/trayicon/frmtest.*
dos2unix examples/trayicon/wndtray.*

# fix rpmlint error "spurious-executable-perm"
chmod 644 docs/booth/ProdProgEntwMitOpenSourceSystems2007.odp

%build
# Don't use -gs (use explicitly "stabs" debuginfo) for compiling lhelp but -g (use the default debuginfo type "dwarf") as in the rest of package's Makefiles
# Fixes the "Stabs debuginfo not supported" error when extracting debug info from the package
sed -i "s/\-gs/\-g/" components/chmhelp/lhelp/Makefile

export FPCDIR=%{_datadir}/fpcsrc/
fpcmake -Tall

MAKEOPTS="-gl -Fl/usr/%{_lib}"
make bigide OPT="$MAKEOPTS"

export LCL_PLATFORM=

# build Qt4 interface
make -C lcl/interfaces/qt all LCL_PLATFORM=qt OPT="-dQT_NATIVE_DIALOGS"

%install
make install \
    INSTALL_PREFIX=%{buildroot}%{_prefix} \
    INSTALL_LIBDIR=%{buildroot}%{_libdir} \
    INSTALL_BINDIR=%{buildroot}%{_bindir} \
    LAZARUS_INSTALL_DIR=%{buildroot}%{_libdir}/%{name} \
    _LIB=%{_lib}

# convenience links
for f in lazarus lazbuild startlazarus; do
    rm -f %{buildroot}%{_bindir}/$f
    ln -sf ../%{_lib}/%{name}/$f %{buildroot}%{_bindir}/$f
done
rm -f %{buildroot}%{_bindir}/lazarus-ide
ln -sf ../%{_lib}/%{name}/lazarus %{buildroot}%{_bindir}/lazarus-ide
for f in lazres lrstolfm updatepofiles; do
    ln -sf ../%{_lib}/%{name}/tools/$f %{buildroot}%{_bindir}/$f
    cat %{buildroot}%{_libdir}/%{name}/install/man/man1/${f}.1 | gzip > %{buildroot}%{_mandir}/man1/${f}.1.gz
done

# collect docs and samples
install -dm 755 %{buildroot}%{_defaultdocdir}/%{name}
mv %{buildroot}%{_libdir}/%{name}/examples %{buildroot}%{_defaultdocdir}/%{name}
ln -s %{_defaultdocdir}/%{name}/examples %{buildroot}%{_libdir}/%{name}/examples
mv %{buildroot}%{_libdir}/%{name}/docs %{buildroot}%{_defaultdocdir}/%{name}
ln -s %{_defaultdocdir}/%{name}/docs %{buildroot}%{_libdir}/%{name}/docs
mv %{buildroot}%{_libdir}/%{name}/COPYING* %{buildroot}%{_libdir}/%{name}/README* %{buildroot}%{_defaultdocdir}/%{name}

# icons
for f in 16 32 48 64 128 256; do
    install -Dpm 0644 images/icons/lazarus${f}x${f}.png %{buildroot}%{_datadir}/icons/hicolor/${f}x${f}/apps/%{name}.png
done

# menu-entry
%if 0%{?suse_version} > 1210
desktop-file-install install/lazarus.desktop
%else
install -Dpm 0644 install/lazarus.desktop %{buildroot}%{_datadir}/applications/%{name}.desktop
%suse_update_desktop_file -n %{name} Development IDE
%endif

# mime info
install -Dpm 0644 install/%{name}-mime.xml %{buildroot}%{_datadir}/mime/packages/%{name}.xml

# configs
install -Dpm 0644 tools/install/linux/editoroptions.xml %{buildroot}%{_sysconfdir}/%{name}/editoroptions.xml
cat tools/install/linux/environmentoptions.xml | sed -e "s#__LAZARUSDIR__#%{_libdir}/%{name}/#" -e "s#__FPCSRCDIR__#%{_datadir}/fpcsrc/#" > %{buildroot}%{_sysconfdir}/%{name}/environmentoptions.xml

# cleanup
rm -rf %{buildroot}%{_libdir}/%{name}/install/man
rm -f %{buildroot}%{_libdir}/%{name}/Makefile.fpc.orig
%if 0%{?suse_version}
%fdupes -s %{buildroot}
%endif

%post
%if 0%{?suse_version} >= 1140
%mime_database_post
%icon_theme_cache_post
%desktop_database_post
%else
/usr/bin/update-mime-database %{_datadir}/mime &> /dev/null || :
%endif

%postun
%if 0%{?suse_version} >= 1140
%mime_database_postun
%icon_theme_cache_postun
%desktop_database_postun
%else
/usr/bin/update-mime-database %{_datadir}/mime &> /dev/null || :
%endif

%files
%defattr(-,root,root,-)
%doc %{_mandir}/man1/*
%doc %{_defaultdocdir}/%{name}
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/editoroptions.xml
%config(noreplace) %{_sysconfdir}/%{name}/environmentoptions.xml
%{_bindir}/%{name}
%{_bindir}/%{name}-ide
%{_bindir}/lazbuild
%{_bindir}/startlazarus
%{_bindir}/lazres
%{_bindir}/lrstolfm
%{_bindir}/updatepofiles
%{_libdir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/icons/hicolor/48x48/mimetypes/*.png
%{_datadir}/pixmaps/lazarus.png
%{_datadir}/mime/packages/%{name}.xml

%changelog
* Fri Nov 18 2016 aloisio@gmx.com
- Update to 1.6.2
  This is a bugfix release. For a complete list of changes see:
  http://wiki.lazarus.freepascal.org/Lazarus_1.6_fixes_branch#Fixes_for_1.6.2_.28merged.29
* Mon Jun 27 2016 termim@gmail.com
- Update to 1.6.0
  http://wiki.freepascal.org/Lazarus_1.6.0_release_notes
  http://wiki.lazarus.freepascal.org/User_Changes_3.0.0
* Sun Oct 18 2015 ecsos@opensuse.org
- update to 1.4.4
  This is a bug fix release. For complete list of changes see
  http://wiki.freepascal.org/Lazarus_1.4_fixes_branch#Fixes_for_1.4.4_.28Merged.29
* Thu Jul 23 2015 ecsos@opensuse.org
- update to 1.4.2
  This is a bug fix release. For complete list of changes see
  http://wiki.freepascal.org/Lazarus_1.4_fixes_branch#Fixes_for_1.4.2_.28Merged.29
* Wed Apr 22 2015 ecsos@opensuse.org
- update to 1.4.0
  This is a major release. For complete list of changes see
  http://wiki.lazarus.freepascal.org/Lazarus_1.4.0_release_notes
* Sat Oct 18 2014 ecsos@opensuse.org
- update to 1.2.6
  This is a bug fix release. For complete list of changes see
  http://wiki.lazarus.freepascal.org/Lazarus_1.2_fixes_branch#Fixes_for_1.2.6_.28Merged.29
* Wed Jul  9 2014 ecsos@opensuse.org
- update to 1.2.4
  This is a bug fix release. For complete list of changes see
  http://wiki.lazarus.freepascal.org/Lazarus_1.2_fixes_branch#Fixes_for_1.2.4_.28Merged.29
* Thu Jan  9 2014 ecsos@opensuse.org
- update to 1.0.14
  This is a bug fix release. For complete list of changes see
  http://wiki.lazarus.freepascal.org/Lazarus_1.0_fixes_branch#Fixes_for_1.0.14_.28Merged.29
* Wed Oct 16 2013 ecsos@opensuse.org
- Update to 1.0.12
  This is a bug fix release. For complete list of changes see
  http://wiki.lazarus.freepascal.org/Lazarus_1.0_fixes_branch#Fixes_for_1.0.12_.28Merged.29
* Wed Aug  7 2013 asterios.dramis@gmail.com
- Update to 1.0.10:
  This is a bug fix release. For complete list of changes see
  http://wiki.lazarus.freepascal.org/Lazarus_1.0_fixes_branch#Fixes_for_1.0.10_.28Merged.29
- Use the package's internal desktop file instead of a custom one. Added a
  patch (lazarus.desktop.patch) to fix it.
- Removed ImageMagick build requirement (not needed).
- Use desktop-file-utils instead of update-desktop-files for openSUSE > 12.1.
  Added desktop-file-utils build requirement for this.
- Install icons in the hicolor icon directory. Added
  icon_theme_cache_post/icon_theme_cache_postun entries for openSUSE >= 11.4 to
  update the icon cache. Added hicolor-icon-theme build requirement for this.
- Added desktop_database_post/desktop_database_postun entries for
  openSUSE >= 11.4 since the package defines a MIME handler. Added
  desktop-file-utils post/postun runtime requirement for this.
- Use mime_database_post/mime_database_postun entries for openSUSE >= 11.4
  instead of /usr/bin/update-mime-database.
* Tue Jan  1 2013 mailaender@opensuse.org
- Update to 1.0.4
  This is a bug fix release. For complete list of changes see
  http://wiki.lazarus.freepascal.org/Lazarus_1.0_fixes_branch#Fixes_for_1.0.4_.28Merged.29
- formal RPMlint fixes
* Mon Dec 10 2012 Greg.Freemyer@gmail.com
- add Requires fpc-src
  If you try to run lazarus without fpc-src you get an error that certain functionality is lost.
  "The sources of the Free Pascal packages are required for browsing and code completion."
* Mon Oct 29 2012 svalx@svalx.net
- Fix building for SLE_11.
* Tue Oct 16 2012 asterios.dramis@gmail.com
- Update to 1.0.2
  This is a bug fix release. For complete list of changes see
  http://wiki.lazarus.freepascal.org/Lazarus_1.0_fixes_branch#Fixes_for_1.0.2_.28Merged.29
- Removed libdb-4_5-devel build requirement (not needed).
- Don't strip binaries (let rpm extract the debug info from the package).
- Don't use -gs (use explicitly "stabs" debuginfo) for compiling lhelp but -g
  (use the default debuginfo type "dwarf") as in the rest of package's
  Makefiles. Fixes the "Stabs debuginfo not supported" error when extracting
  debug info from the package.
* Thu Oct  4 2012 asterios.dramis@gmail.com
- Fix lazarus dir in /etc/lazarus/environmentoptions.xml (use
  /usr/lib64/lazarus for x86_64).
- Removed gtk2 build requirement (not needed).
- Use Requires(post/postun) for shared-mime-info instead of PreReq for the
  post/postun update-mime-database execution.
- Removed Fedora related stuff (incomplete).
- Spec file updates based also on spec-cleaner run.
- Updated lazarus.desktop file to be xdg compatible.
* Sun Sep 23 2012 termim@gmail.com
- Update to 1.0.0
  This is a major release. For complete list of changes see
  http://wiki.lazarus.freepascal.org/Lazarus_1.0_release_notes
* Fri Apr  1 2011 termim@gmail.com
- Update to 0.9.30
* Tue Nov  3 2009 Toni Graffy <toni@links2linux.de> - 0.9.28.2-1.pm.1
- fixed configfile environmentoptions.xml
* Sun Nov  1 2009 Toni Graffy <toni@links2linux.de> - 0.9.28.2-0.pm.1
- update to 0.9.28.2
- This release fixes compiling a test application without saving (missing
  project1.lrs). The Lazarus directory is now set correctly by the deb package.
  Some other small fixes are also included.
* Tue Oct 27 2009 Toni Graffy <toni@links2linux.de> - 0.9.28-0.pm.1
- update to 0.9.28
-  In this major release, the IDE has many source editor improvements like display
  of "double width" fonts (such as Eastern, Japanese, Chinese, and Arabic), better
  code folding, highlighting, syncro editing, and persistent blocks. The debugger
  has assembler windows, easier exception handling, and breakpoint properties. The
  LCL now uses GTK2 as the default widgetset on Linux and BSD and includes the
  TMonitor class for multi-monitor support. Refactoring of LCL reduced the minimum
  size of executables by about 15%%. The support of TFrame support has improved, so
  you can visually nest designers in the IDE.
* Mon May  4 2009 Toni Graffy <toni@links2linux.de> - 0.9.26.2-0.pm.3
- rebuild against fpc-2.2.4
* Mon Mar 23 2009 Toni Graffy <toni@links2linux.de> - 0.9.26.2-0.pm.2
- update to 0.9.26.2 (release-tarball)
* Sat Feb 28 2009 Toni Graffy <toni@links2linux.de> - 0.9.26.2-0.pm.1
- update to 0.9.26.2
  svn co https://lazarus.svn.sourceforge.net/svnroot/lazarus/tags/lazarus_0_9_26_2 lazarus
* Sat Nov  1 2008 Toni Graffy <toni@links2linux.de> - 0.9.26-0.pm.2
- rebuild against fpc-2.2.2-0.pm.2
* Thu Oct 30 2008 Toni Graffy <toni@links2linux.de> - 0.9.26-0.pm.1
- initial build for packman (fpc-2.2.2 is working with this version)
- based on fedora spec-file from Lubomir Rintel <lkundrak@v3.sk>
